@@ -184,7 +184,7 @@ package Sidef::Object::Object {
                         my $v = $obj->{$_};
                         my $r = Scalar::Util::reftype($v);
                         ($_ => ($r eq 'HASH' || $r eq 'ARRAY' ? __SUB__->($v, $r) : $v))
-                      } CORE::keys(%{$obj})
+                    } CORE::keys(%{$obj})
                 );
                 $o;
             }
@@ -195,7 +195,7 @@ package Sidef::Object::Object {
                     map {
                         my $r = Scalar::Util::reftype($_);
                         $r eq 'ARRAY' || $r eq 'HASH' ? __SUB__->($_, $r) : $_
-                      } @{$obj}
+                    } @{$obj}
                 );
                 $o;
             }
@@ -266,16 +266,21 @@ package Sidef::Object::Object {
 
             my $type = Sidef::normalize_type(CORE::ref($obj) ? CORE::ref($obj) : $obj);
             Scalar::Util::reftype($obj) eq 'HASH' or return $type;
-            my @keys = CORE::sort CORE::keys(%{$obj});
+            my @keys = CORE::sort(CORE::keys(%{$obj}));
 
             my $str = Sidef::Types::String::String->new($type . "(#`($refaddr)...)");
+
             $addr{$refaddr} = $str;
 
             $$str = (
                 "$type(" . CORE::join(
                     ', ',
                     map {
-                        my $str = UNIVERSAL::can($obj->{$_}, 'dump') ? $obj->{$_}->dump : "$obj->{$_}";
+                        my $str = (
+                                   defined($obj->{$_})
+                                   ? (UNIVERSAL::can($obj->{$_}, 'dump') ? $obj->{$_}->dump : "$obj->{$_}")
+                                   : 'nil'
+                                  );
                         "$_: $str";
                       } @keys
                   )
